@@ -671,11 +671,6 @@ func (s *SourceState) Apply(
 	return PersistentStateSet(persistentState, EntryStateBucket, targetAbsPath.Bytes(), targetEntryState)
 }
 
-// Contains returns the source state entry for targetRelPath.
-func (s *SourceState) Contains(targetRelPath RelPath) bool {
-	return s.root.Get(targetRelPath) != nil
-}
-
 // Encryption returns s's encryption.
 func (s *SourceState) Encryption() Encryption {
 	return s.encryption
@@ -722,6 +717,11 @@ func (s *SourceState) ForEach(f func(RelPath, SourceStateEntry) error) error {
 	})
 }
 
+// Get returns the source state entry for targetRelPath.
+func (s *SourceState) Get(targetRelPath RelPath) SourceStateEntry {
+	return s.root.Get(targetRelPath)
+}
+
 // Ignore returns if targetRelPath should be ignored.
 func (s *SourceState) Ignore(targetRelPath RelPath) bool {
 	s.Lock()
