@@ -120,6 +120,7 @@ type ConfigFile struct {
 	AWSSecretsManager awsSecretsManagerConfig `json:"awsSecretsManager" mapstructure:"awsSecretsManager" yaml:"awsSecretsManager"` //nolint:lll
 	Bitwarden         bitwardenConfig         `json:"bitwarden" mapstructure:"bitwarden" yaml:"bitwarden"`
 	Dashlane          dashlaneConfig          `json:"dashlane" mapstructure:"dashlane" yaml:"dashlane"`
+	Ejson             ejsonConfig             `json:"ejson" mapstructure:"ejson" yaml:"ejson"`
 	Gopass            gopassConfig            `json:"gopass" mapstructure:"gopass" yaml:"gopass"`
 	Keepassxc         keepassxcConfig         `json:"keepassxc" mapstructure:"keepassxc" yaml:"keepassxc"`
 	Keeper            keeperConfig            `json:"keeper" mapstructure:"keeper" yaml:"keeper"`
@@ -379,6 +380,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"dashlanePassword":         c.dashlanePasswordTemplateFunc,
 		"decrypt":                  c.decryptTemplateFunc,
 		"deleteValueAtPath":        c.deleteValueAtPathTemplateFunc,
+		"ejsonDecrypt":             c.ejsonDecryptTemplateFunc,
+		"ejsonDecryptWithKey":      c.ejsonDecryptWithKeyTemplateFunc,
 		"encrypt":                  c.encryptTemplateFunc,
 		"eqFold":                   c.eqFoldTemplateFunc,
 		"fromIni":                  c.fromIniTemplateFunc,
@@ -397,6 +400,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"includeTemplate":          c.includeTemplateTemplateFunc,
 		"ioreg":                    c.ioregTemplateFunc,
 		"joinPath":                 c.joinPathTemplateFunc,
+		"jq":                       c.jqTemplateFunc,
 		"keepassxc":                c.keepassxcTemplateFunc,
 		"keepassxcAttachment":      c.keepassxcAttachmentTemplateFunc,
 		"keepassxcAttribute":       c.keepassxcAttributeTemplateFunc,
@@ -667,10 +671,7 @@ func (c *Config) createAndReloadConfigFile(cmd *cobra.Command) error {
 	}
 
 	if configTemplate == nil {
-		if err := c.persistentState.Delete(chezmoi.ConfigStateBucket, configStateKey); err != nil {
-			return err
-		}
-		return nil
+		return c.persistentState.Delete(chezmoi.ConfigStateBucket, configStateKey)
 	}
 
 	configFileContents, err := c.createConfigFile(configTemplate.targetRelPath, configTemplate.contents, cmd)
@@ -710,11 +711,7 @@ func (c *Config) createAndReloadConfigFile(cmd *cobra.Command) error {
 	if err := c.decodeConfigBytes(configTemplate.format, configFileContents, &c.ConfigFile); err != nil {
 		return fmt.Errorf("%s: %w", configTemplate.sourceAbsPath, err)
 	}
-	if err := c.setEncryption(); err != nil {
-		return err
-	}
-
-	return nil
+	return c.setEncryption()
 }
 
 // createConfigFile creates a config file using a template and returns its
@@ -854,10 +851,7 @@ func (c *Config) decodeConfigMap(configMap map[string]any, configFile *ConfigFil
 	if err != nil {
 		return err
 	}
-	if err := decoder.Decode(configMap); err != nil {
-		return err
-	}
-	return nil
+	return decoder.Decode(configMap)
 }
 
 // defaultPreApplyFunc is the default pre-apply function. If the target entry
@@ -1580,7 +1574,7 @@ func (c *Config) persistentPostRunRootE(cmd *cobra.Command, args []string) error
 			var format chezmoi.Format
 			if format, err = chezmoi.FormatFromAbsPath(c.configFileAbsPath); err == nil {
 				var config map[string]any
-				if err = format.Unmarshal(configFileContents, &config); err != nil {
+				if err = format.Unmarshal(configFileContents, &config); err != nil { //nolint:revive
 					// err is already set, do nothing.
 				} else {
 					err = c.decodeConfigMap(config, &ConfigFile{})
@@ -1928,6 +1922,9 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 	} {
 		scriptEnv = append(scriptEnv, "CHEZMOI_"+key+"="+value)
 	}
+	if c.Verbose {
+		scriptEnv = append(scriptEnv, "CHEZMOI_VERBOSE=1")
+	}
 	for groupKey, group := range map[string]map[string]any{
 		"KERNEL":          templateData.Kernel,
 		"OS_RELEASE":      templateData.OSRelease,
@@ -2243,7 +2240,7 @@ func (c *Config) targetRelPaths(
 			return nil, err
 		}
 		if options.mustBeInSourceState {
-			if !sourceState.Contains(targetRelPath) {
+			if sourceState.Get(targetRelPath) == nil {
 				return nil, fmt.Errorf("%s: not in source state", arg)
 			}
 		}
@@ -2450,6 +2447,9 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 		Dashlane: dashlaneConfig{
 			Command: "dcli",
 		},
+		Ejson: ejsonConfig{
+			KeyDir: firstNonEmptyString(os.Getenv("EJSON_KEYDIR"), "/opt/ejson/keys"),
+		},
 		Gopass: gopassConfig{
 			Command: "gopass",
 		},
